/*
 * Java
 *
 * Copyright 2015 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.rcommand.impl;

import java.io.IOException;
import java.io.InputStream;

public class LimitedLengthInputStream extends InputStream {
	private boolean eof;
	private int remainingLength;
	private final InputStream in;
	/*default*/static final int CHUNCKS_SIZE = Integer.getInteger("ej.rcommand.chunks.size", 2048);

	public LimitedLengthInputStream() {
		this.eof = true;
		this.in = null;
	}

	public LimitedLengthInputStream(InputStream in, int length) {
		if (length <= 0) {
			this.eof = true;
			this.in = null;
		} else {
			this.eof = false;
			this.in = in;
			this.remainingLength = length;
		}
	}

	@Override
	public int available() throws IOException {
		if (this.eof) {
			return 0;
		} else {
			return this.remainingLength;
		}
	}

	@Override
	public void close() throws IOException {
		if (! eof) {
			byte[] chuncks = new byte[CHUNCKS_SIZE];
			while (read(chuncks) != -1) {
				// do nothing
				// just consume the input stream
			}
			this.eof = true;
		}
	}

	@Override
	public synchronized void mark(int readlimit) {
		// not supported
	}

	@Override
	public boolean markSupported() {
		return false;
	}

	@Override
	public int read() throws IOException {
		if (this.eof) {
			return -1;
		}

		int r = this.in.read();
		this.remainingLength--;
		if (r == -1 || this.remainingLength == 0) {
			this.eof = true;
		}

		return r;
	}

	@Override
	public int read(byte[] b, int off, int len) throws IOException {
		if (this.eof) {
			return -1;
		}

		int r = this.in.read(b, off, Math.min(this.remainingLength, len));
		this.remainingLength -= r;
		if (r == -1 || this.remainingLength == 0) {
			this.eof = true;
		}

		return r;
	}

	@Override
	public synchronized void reset() throws IOException {
		// not supported
	}

	@Override
	public long skip(long n) throws IOException {
		if (this.eof) {
			return 0;
		}

		long r = this.in.skip(Math.min(this.remainingLength, n));
		this.remainingLength -= r;
		if (this.remainingLength == 0) {
			this.eof = true;
		}

		return r;
	}

}
